=======
History
=======

0.0.4 (2024-02-01)
------------------

* Fix for querying by source package even if the package was a copy from a previous Ubuntu release.

0.0.3 (2024-01-31)
------------------

* Allow for querying by source package.

0.0.2 (2024-01-24)
------------------

* No longer iterate over pocket and publication status for much quicker query times.

0.0.1 (2024-01-24)
------------------

* First release on PyPI.
